#!/usr/bin/ksh
# Licensed Materials - Property of IBM
#
# (C) Copyright IBM Corp. 2013 All Rights Reserved
#
# US Government Users Restricted Rights - Use, duplicate or
# disclosure restricted by GSA ADP Schedule Contract with
# IBM Corp.

# --------------------------------------------------------------------------
# Verifies the status of the various services needed by the given 
# agent type.
#
# @param
#	agent_type=<common, platform>
#			Common Agent or Platform Agent.
#			The following services will be checked for Common Agent:
#			1. slp daemon
#			2. common agent process
#
#			The following services will be checked for Platform Agent:
#			1. slp daemon
#			2. cimsys subsystem
#			3. platform_agent subsystem
#
# @return
#	result=success
#			Overall operation succeed. Detailed status is given by the 
#			<service_RC> keys.
#
#	slp_RC={success, fail, notfound}
#	common_RC={success, fail, notfound}
#	cimserver_RC={success, fail, notfound}
#	platform_agent_RC={success, fail, notfound}
#
#	result=fail
#			Overall operation failed (wrong commands, the command
#			to evaluate failed or the command was not found.
#
# ---------------------------------------------------------------------------

agent_type="$(echo $1 | awk '{ {split($1, split_result, "=")} {print split_result[2]} }')"

# -----------------------------------------------
# SLP common to both platform and common agents
# -----------------------------------------------
ps -ef | grep slp_srvreg | grep -v grep >/dev/null 2>&1
RC=$?
if [ "$RC" != "0" ]; then
	slp_RC="slp_RC=fail"
else
	slp_RC="slp_RC=success"
fi

# -----------------------------------------------
# Common Agent specific service which is the 
# common agent itself
# -----------------------------------------------
if [ "$agent_type" = "common" ]; then
	
	/opt/ibm/director/agent/runtime/agent/bin/endpoint.sh status | grep Subsystem >/dev/null 2>&1
	RC=$?
	if [ "$RC" = "0" ]; then
		# ---------------------------------------------------
		# This endpoint.sh status uses the new status format
		# (subsystem status)
		# ---------------------------------------------------
		/opt/ibm/director/agent/runtime/agent/bin/endpoint.sh status | grep -i active >/dev/null 2>&1
		status_RC=$?	
	else
		# ---------------------------------------------------
		# This endpoint.sh status uses the new old status 
		# format (of the nonstop service)
		# ---------------------------------------------------
		/opt/ibm/director/agent/runtime/agent/bin/endpoint.sh status | grep -i running >/dev/null 2>&1
		status_RC=$?
	fi
	
	if [ "$status_RC" != "0" ]; then
		common_RC="common_RC=fail"		
	else
		common_RC="common_RC=success"
	fi
fi

# -----------------------------------------------
# Platform Agent specific services 
# -----------------------------------------------
if [ "$agent_type" = "platform" ]; then
	if [[ ! -a /usr/bin/lssrc ]]; then 
		echo "result=fail"
		exit 0;
	fi	
	
	
	# -----------------------------------------------
	# Check to see if platform agent subsystems indeed
	# registered (found).
	# -----------------------------------------------
	/usr/bin/lssrc -s platform_agent >/dev/null 2>&1
	RC=$?
	
	if [ "$RC" != "0" ]; then
		echo "result=fail,platform_agent_RC=notfound"
		exit 0;
	fi
	
	/usr/bin/lssrc -s cimsys >/dev/null 2>&1
	RC=$?
	
	if [ "$RC" != "0" ]; then
		echo "result=fail,cimserver_RC=notfound"
		exit 0;
	fi
	
	/usr/bin/lssrc -s platform_agent | grep -i active >/dev/null 2>&1  
	RC=$?
	
	if [ "$RC" != "0" ]; then
		platform_agent_RC="platform_agent_RC=fail"
	else
		platform_agent_RC="platform_agent_RC=success"
	fi
	 
	/usr/bin/lssrc -s cimsys | grep active  >/dev/null 2>&1
	RC=$?
	
	if [ "$RC" != "0" ]; then
		cimserver_RC="cimserver_RC=fail"
	else
		cimserver_RC="cimserver_RC=success"
	fi

fi

	
# ---------------------------------------------------------
# We were able to grab the services status so output them
# ---------------------------------------------------------

if [ "$agent_type" = "common" ]; then
	echo "result=success,$slp_RC,$common_RC"
else
	if [ "$agent_type" = "platform" ]; then
		echo "result=success,$slp_RC,$cimserver_RC,$platform_agent_RC"
	fi
fi
