#! /bin/bash
# Licensed Materials - Property of IBM
#
# (C) Copyright IBM Corp. 2013 All Rights Reserved
#
# US Government Users Restricted Rights - Use, duplicate or
# disclosure restricted by GSA ADP Schedule Contract with
# IBM Corp.

# --------------------------------------------------------------------------
# Verifies the status of the various services needed by the given 
# agent type.
#
# @param
#	agent_type=<common, platform>
#			Common Agent or Platform Agent.
#			The following services will be checked for Common Agent:
#			1. slp daemon
#			2. common agent process
#
#			The following services will be checked for Platform Agent:
#			1. slp daemon
#			2. cimlistener
#			3. cimserver
#			4. tier1slp
#
#
# @return
#	result=success
#			Overall operation succeed. Detailed status is given by the 
#			<service_RC> keys.
#
#	slp_RC={success, fail, notfound}
#	common_RC={success, fail, notfound}
#	cimlistener_RC={success, fail, notfound}
#	cimserver_RC={success, fail, notfound}
#	tier1slp_RC={success, fail, notfound}
#
#	result=fail
#			Overall operation failed (wrong commands, the command
#			to evaluate failed or the command was not found.
#
# ---------------------------------------------------------------------------

agent_type="$(echo $1 | awk '{ {split($1, split_result, "=")} {print split_result[2]} }')"

# -----------------------------------------------
# SLP common to both platform and common agents
# -----------------------------------------------

if [ -e /etc/init.d/ibmsa ]; then
        slp_status_cmd="/etc/init.d/ibmsa status"
else
		if [ -e /etc/init.d/paslpd ]; then
        		slp_status_cmd="/etc/init.d/paslpd status"
		else
				echo "result=fail,slp_RC=notfound"
				exit 0
		fi
fi


# -----------------------------------------------
# Platform Agent specific services 
# -----------------------------------------------


if [ "$agent_type" = "platform" ]; then

	if [ ! -e /etc/init.d/cimlistenerd ]; then
			echo "result=fail,cimlistenerd_RC=notfound"
			exit 0
	else
			cimlistener_status_cmd="/etc/init.d/cimlistenerd status"
	fi

	if [ ! -e /etc/init.d/cimserverd ]; then
			echo "result=fail,cimserverd_RC=notfound"
			exit 0
	else
			cimserver_status_cmd="/etc/init.d/cimserverd status"
	fi
	
	if [ ! -e /etc/init.d/tier1slpinst ]; then
			echo "result=fail,cimtierslp_RC=notfound"
			exit 0
	else
			cimtierslp_status_cmd="/etc/init.d/tier1slpinst status"
	fi
fi

# -----------------------------------------------
#
# Actual Status Check .....
#
# Note: /etc/init.d/paslpd status reports 
#		slpd is not running
#		slpd is running
# While the other SLP service has "is stopped" 
# wording and has "is running" workind when run.
# So we explicitly look for "is running"
#
# -----------------------------------------------

slp_status="$($slp_status_cmd | grep -i "is running")"

if [ "x$slp_status" = "x" ]; then

		slp_RC="slp_RC=fail"
else
		slp_RC="slp_RC=success"
fi

# -----------------------------------------------
# Common Agent specific service which is the 
# common agent itself
# -----------------------------------------------
if [ "$agent_type" = "common" ]; then
		common_status="$(/opt/ibm/director/agent/runtime/agent/bin/endpoint.sh status | grep -i running)"
		
		if [ "x$common_status" = "x" ]; then
			common_RC="common_RC=fail"
		
		else
			common_RC="common_RC=success"
		fi
fi

# -----------------------------------
# Platform Agent specific services 
# -----------------------------------

if [ "$agent_type" = "platform" ]; then

		cimlistener_status="$($cimlistener_status_cmd | grep -i running)"
		if [ "x$cimlistener_status" = "x" ]; then

				cimlistener_RC="cimlistener_RC=fail"
		
		else
				cimlistener_RC="cimlistener_RC=success"
		fi
		
		cimserver_status="$($cimserver_status_cmd | grep -i running)"
		if [ "x$cimserver_status" = "x" ]; then

				cimserver_RC="cimserver_RC=fail"
				
		else
				cimserver_RC="cimserver_RC=success"
		fi
		
		cimtierslp_status="$($cimtierslp_status_cmd | grep -i "TIER1SLP running")"
		if [ "x$cimtierslp_status" = "x" ]; then

				tier1slp_RC="tier1slp_RC=fail"
		else
				tier1slp_RC="tier1slp_RC=success"
		fi
fi

# ---------------------------------------------------------
# We were able to grab the services status so output them
# ---------------------------------------------------------

if [ "$agent_type" = "common" ]; then
		echo "result=success,$slp_RC,$common_RC"
else
		if [ "$agent_type" = "platform" ]; then

				echo "result=success,$slp_RC,$cimlistener_RC,$cimserver_RC,$tier1slp_RC"
		fi
fi
